summaryrefslogtreecommitdiff
path: root/include/ec_commands.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ec_commands.h')
-rw-r--r--include/ec_commands.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/include/ec_commands.h b/include/ec_commands.h
index f64ffd6eac..fa820b7ebb 100644
--- a/include/ec_commands.h
+++ b/include/ec_commands.h
@@ -2842,14 +2842,18 @@ struct ec_params_current_limit {
} __packed;
/*
* Set maximum external power current.
*/
-#define EC_CMD_EXT_POWER_CURRENT_LIMIT 0xa2
+#define EC_CMD_EXTERNAL_POWER_LIMIT 0xa2
-struct ec_params_ext_power_current_limit {
- uint32_t limit; /* in mA */
+/* Command v0 is used only on Spring and is obsolete + unsupported */
+struct ec_params_external_power_limit_v1 {
+ uint16_t current_lim; /* in mA, or EC_POWER_LIMIT_NONE to clear limit */
+ uint16_t voltage_lim; /* in mV, or EC_POWER_LIMIT_NONE to clear limit */
} __packed;
+#define EC_POWER_LIMIT_NONE 0xffff
+
/*****************************************************************************/
/* Smart battery pass-through */
@@ -2842,14 +2842,18 @@ struct ec_params_current_limit {
} __packed;
/*
- * Set maximum external power current.
+ * Set maximum external voltage / current.
*/